# systemd options
%global _has_systemd %(eval rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  # this is usually either `common.service' or `%{_has_systemd}.service'
  %global _servicefile_postfix common.service
%else
  %global _servicefile_postfix init
%endif

%global username dhcphelp

Summary: A relay for Dynamic Host Configuration Protocol
Name: dhcp-helper
Version: 1.2
Release: 4%{?dist}
License: GPL-2.0-or-later AND GPL-3.0-only
Group: System Environment/Daemons
URL: http://thekelleys.org.uk/dhcp-helper/
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
Source0: http://thekelleys.org.uk/%{name}/%{name}-%{version}.tar.gz
Source1: %{name}.%{_servicefile_postfix}
Source2: %{name}.sysconfig
Patch0: dhcp-helper-1.2-user.patch
%if %{_has_systemd}
Patch1: dhcp-helper-1.2-systemd_rundir.patch
BuildRequires: systemd
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif
Requires(pre): %{_sbindir}/groupadd, %{_sbindir}/useradd
BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
Dhcp-helper is a DHCP and BOOTP relay agent. It listens for DHCP and
BOOTP broadcasts on directly connected subnets and relays them to
DHCP or BOOTP servers elsewhere. Dhcp-helper does not require the Packet
Filter kernel facility to be present. This makes it a good choice for
use on small or embedded systems. Dhcp-helper can be configured to
forward DHCP requests as broadcasts, and therefore does not need to be
given the IP address of the DHCP server, only the network in which it
resides.

%prep
%setup -q
%patch0 -p1 -b .user
%if %{_has_systemd}
%patch1 -p1 -b .systemd_rundir
%endif

%build
%{__make} CFLAGS="" version="%{version}"

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}
 
%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
%endif

%{__install} -m 0644 -p %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}

%{__make} install DESTDIR=%{buildroot} INSTALL="install -p" PREFIX=%{_prefix} MANDIR=%{_mandir} CFLAGS="" version="%{version}"

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%pre
getent group %{username} > /dev/null || %{_sbindir}/groupadd -r %{username} 2> /dev/null || :
getent passwd %{username} > /dev/null || \
  %{_sbindir}/useradd -g %{username} -s /sbin/nologin -r -c "DHCP Relay Agent" -d / %{username} 2> /dev/null || :

%post
%if %{_has_systemd}
%systemd_post %{name}.service
%else
/sbin/chkconfig --add %{name}
%endif

%preun
%if %{_has_systemd}
%systemd_preun %{name}.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}
fi
%endif

%postun
%if %{_has_systemd}
%systemd_postun_with_restart %{name}.service
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc CHANGELOG COPYING* README
%if %{_has_systemd}
%{_unitdir}/%{name}.service
%else
%config %{_initrddir}/%{name}
%endif
%{_sbindir}/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%{_mandir}/man8/%{name}.8*

%changelog
* Fri Sep 20 2024 Simon Matter <simon.matter@invoca.ch> 1.2-4
- fix service file

* Mon Jan 11 2021 Simon Matter <simon.matter@invoca.ch> 1.2-3
- run as user dhcphelp

* Tue Apr 21 2020 Simon Matter <simon.matter@invoca.ch> 1.2-2
- add support for EL8

* Tue Jul 28 2015 Simon Matter <simon.matter@invoca.ch> 1.2-1
- upgrade to 1.2

* Fri May 22 2015 Simon Matter <simon.matter@invoca.ch> 1.1-3
- add support for systemd

* Thu Apr 04 2013 Simon Matter <simon.matter@invoca.ch> 1.1-1
- initial build
